/*
 * Copyright (C) 2012 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.builder;

import junit.framework.TestCase;

import java.io.File;
import java.io.IOException;

/**
 * Utility methods to deal with loading the test data.
 */
public class TestUtils {

    /**
     * returns a File for the subfolder of the test resource data.
     *
     * This is basically "src/test/resources/testData/$name".
     *
     * Note that this folder is relative to the root project which is where gradle
     * sets the current working dir when running the tests.
     *
     * If you need a full folder path, use {@link #getCanonicalRoot(String)}.
     *
     * @param name the name of the subfolder.
     * @return a File
     */
    public static File getRoot(String name) {
        File root = new File("src/test/resources/testData/" + name);
        TestCase.assertTrue("Test folder '" + name + "' does not exist!",
                root.isDirectory());

        return root;
    }

    /**
     * returns a File for the subfolder of the test resource data.
     *
     * The full path is canonized.
     * This is basically ".../src/test/resources/testData/$name".
     *
     * @param name the name of the subfolder.
     * @return a File
     */
    public static File getCanonicalRoot(String name) throws IOException {
        File root = getRoot(name);
        return root.getCanonicalFile();
    }
}
